# avrodantic

CLI tool to parse AVRO schemas into pydantic models.

## Installation

```console
pip install avrodantic
```

## License

`avrodantic` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
